import 'package:yflutter_widgets/configs/screenutil_creator.dart';
import 'package:yflutter_widgets/widgets/tagsgridview/ytag_item.dart';
import 'package:flutter/widgets.dart';
import 'package:flutter/material.dart';

/// Tags Grid View.
class YTagsGridView extends StatefulWidget {
  YTagsGridView(
      {@required this.tagList,
      this.selectable = false,
      this.selectedIndex = 0,
      this.selectCallback});

  // The tags list, only <String> now.
  final List<String> tagList;
  // This Tag Grid can be selected or not, default False.
  final bool selectable;
  // If the selectable is true, thus, set the selectedIndex,
  // should larger than 0 and smaller than tagList.length.
  final selectedIndex;
  // The callback when user tap a Tag item.
  final ValueChanged selectCallback;

  @override
  _YTagsGridViewState createState() => _YTagsGridViewState();
}

class _YTagsGridViewState extends State<YTagsGridView> {
  int _currentIndex = 0;

  @override
  void initState() {
    super.initState();
    _currentIndex = widget.selectedIndex;
  }

  @override
  Widget build(BuildContext context) {
    return GridView.count(
      padding: EdgeInsets.only(
          top: ScreenUtilCreator().setWidth(16),
          right: ScreenUtilCreator().setWidth(16),
          left: ScreenUtilCreator().setWidth(16),
          bottom: ScreenUtilCreator().setWidth(16)),
      crossAxisCount: 3,
      physics: NeverScrollableScrollPhysics(),
      scrollDirection: Axis.vertical,
      crossAxisSpacing: ScreenUtilCreator().setSp(24),
      mainAxisSpacing: ScreenUtilCreator().setSp(18),
      shrinkWrap: true,
      reverse: false,
      childAspectRatio: 110 / 36,
      children: List.generate(
          widget.tagList.length,
          (index) => Container(
                // child: Text("Hello"),
                child: GestureDetector(
                    onTap: !widget.selectable
                        ? null
                        : () {
                            if (widget.selectCallback != null)
                              widget.selectCallback(index);
                            setState(() {
                              _currentIndex = index;
                            });
                            // widget.selectCallback(index);
                          },
                    child: widget.selectable
                        ? YTagItem(
                            content: widget.tagList[index],
                            isSelected: _currentIndex == index,
                          )
                        : YTagItem(
                            content: widget.tagList[index],
                          )),
              )),
    );
  }
}
